<?php

namespace Drupal\legal_text\Form;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure legal text form.
 */
class EntityLegalTextSettingsForm extends ConfigFormBase {

  /**
   * The entity type manager.
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->entityTypeManager = $container->get('entity_type.manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'legal_text_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'legal_text.settings',
    ];
  }

  /**
   * Implements \Drupal\Core\Form\FormInterface::buildForm().
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $existingContentTypeOptions = $this->getExistingContentTypes();
    $config = $this->config('legal_text.settings');
    $form['legal_text'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Legal Text'),
      '#default_value' => $config->get('legal_text'),
      '#description' => $this->t('Enter your legal text in this text area.'),
      '#required' => TRUE,
    ];
    $form['bundles'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Select Bundles'),
      '#options' => $existingContentTypeOptions,
      '#default_value' => $config->get('bundles'),
      '#description' => $this->t('Select the content types for which you would like to enable legal text.'),
      '#required' => TRUE,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Save the configuration.
    $this->configFactory->getEditable('legal_text.settings')
      ->set('legal_text', $form_state->getValue('legal_text'))
      ->set('bundles', $form_state->getValue('bundles'))
      ->save();

    // Clear the static cache after updating the configuration.
    $this->configFactory->clearStaticCache();

    // Invalidate cache tags associated with the configuration.
    Cache::invalidateTags(['config:legal_text.settings']);

    // Call parent submit function.
    parent::submitForm($form, $form_state);
  }

  /**
   * Returns a list of all the content types currently installed.
   *
   * @return array
   *   An array of content types.
   */
  public function getExistingContentTypes() {
    $types = [];
    $contentTypes = $this->entityTypeManager->getStorage('node_type')->loadMultiple();
    foreach ($contentTypes as $contentType) {
      $types[$contentType->id()] = $contentType->label();
    }
    return $types;
  }

}
